const app = getApp()

import Dialog from '@vant/weapp/dialog/dialog';
import Notify from '@vant/weapp/notify/notify';

import {
    selfFormatTimeYMD,
    selfFormatTimeHM,
    checkIsImg
} from "../../../../utils/util.js"


import {
    repairListRq
} from "../../../../api/repair/repair.js"


Page({

    /**
     * 页面的初始数据
     */
    data: {
        // tabBar param
        tabBarParam: {
            selected: 0,
            color: "#515151",
            selectedColor: "#217CFF",
            backgroundColor: "#ffffff",
        },
        // tabBar menu
        tabBarList: [{
                "pagePath": "/pages/index/index",
                "iconPath": "/images/tabbar/home.png",
                "selectedIconPath": "/images/tabbar/home-select.png",
                "text": "首页"
            },
            {
                "pagePath": "/pages/reportRepair/report/report",
                "iconPath": "/images/tabbar/center.png",
                "selectedIconPath": "/images/tabbar/center.png",
                "text": "报修",
                "bulge": true,
            },
            {
                "pagePath": "/pages/my/my",
                "iconPath": "/images/tabbar/my.png",
                "selectedIconPath": "/images/tabbar/my-select.png",
                "text": "我的"
            },
        ],
        IMG_NAME: app.IMG_NAME,
        userData: null,
        dataChange: false,
        tabTitle: '待派单', // tab 标题
        resendOrderVisible: false, // 重新派单显示
        // 重新派单
        resendOrder: {
            pageNum: 1,
            pageSize: 10,
            type: 'anew',
            dataList: [],
            isDataAll: false,
        },
        // 待派单
        pendingOrder: {
            pageNum: 1,
            pageSize: 10,
            type: 'wait',
            dataList: [],
            isDataAll: false,
        },
        // 已派单
        assignOrder: {
            pageNum: 1,
            pageSize: 10,
            type: 'already',
            dataList: [],
            isDataAll: false,
        },
        // 已关闭
        closeOrder: {
            pageNum: 1,
            pageSize: 10,
            type: 'close',
            dataList: [],
            isDataAll: false,
        },
    },

    /**
     * 生命周期函数--监听页面加载
     */
    onLoad(options) {
        let _this = this;
        _this.setData({
            userData: wx.getStorageSync('user'),
        })
        // 数据
        // 角色id
        let dataType = _this.data.userData.dataType
        // 是否展示
        if (dataType == 7) {
            _this.setData({
                tabTitle: '重新派单', // tab 标题
                resendOrderVisible: true, // 重新派单显示
            })
        }
    },

    // 切换tabbar
    switchTab(e) {
        const data = e.currentTarget.dataset
        console.log('switchTab', data)
        const url = data.path
        if (url == '/pages/reportRepair/report/report') {
            wx.navigateTo({
                url
            })
        } else {
            wx.switchTab({
                url
            })
        }
    },

    // 获取数据
    getDataList(transferTabTitle) {
        // 获取参数
        let _this = this;
        let tabTitle = _this.data.tabTitle
        if (transferTabTitle) {
            tabTitle = transferTabTitle
        }
        let userId = _this.data.userData.id
        let pageNum = null
        let pageSize = null
        let type = null
        let isDataAll = null

        //
        let resendOrder = _this.data.resendOrder
        let pendingOrder = _this.data.pendingOrder
        let assignOrder = _this.data.assignOrder
        let closeOrder = _this.data.closeOrder

        if (tabTitle == '重新派单') {
            pageNum = resendOrder.pageNum
            pageSize = resendOrder.pageSize
            type = resendOrder.type
            isDataAll = resendOrder.isDataAll

        } else if (tabTitle == '待派单') {
            pageNum = pendingOrder.pageNum
            pageSize = pendingOrder.pageSize
            type = pendingOrder.type
            isDataAll = pendingOrder.isDataAll

        } else if (tabTitle == '已派单') {
            pageNum = assignOrder.pageNum
            pageSize = assignOrder.pageSize
            type = assignOrder.type
            isDataAll = assignOrder.isDataAll

        } else if (tabTitle == '已关闭') {
            pageNum = closeOrder.pageNum
            pageSize = closeOrder.pageSize
            type = closeOrder.type
            isDataAll = closeOrder.isDataAll

        } else {
            wx.showToast({
                title: `tab 切换错误(${tabTitle})`,
                icon: 'none',
            });
            return;
        }

        // 判断数据是否已全部加载
        if (isDataAll) {
            return;
        }
        // 传递参数
        let param = {
            pageNum,
            pageSize,
            menu: '3', // 派单
            type,
        }
        // 查询数据        
        repairListRq(param).then(res => {
            console.log('repairListRq', res);
            let dataList = res.rows
            let isDataAll = false
            if (pageNum * pageSize >= res.total) {
                isDataAll = true
            }
            //
            if (tabTitle == '重新派单') {
                resendOrder.dataList = resendOrder.dataList.concat(_this.formartData(dataList))
                resendOrder.pageNum = resendOrder.pageNum + 1
                resendOrder.isDataAll = isDataAll
                _this.setData({
                    resendOrder
                })

            } else if (tabTitle == '待派单') {
                pendingOrder.dataList = pendingOrder.dataList.concat(_this.formartData(dataList))
                pendingOrder.pageNum = pendingOrder.pageNum + 1
                pendingOrder.isDataAll = isDataAll
                _this.setData({
                    pendingOrder
                })

            } else if (tabTitle == '已派单') {
                assignOrder.dataList = assignOrder.dataList.concat(_this.formartData(dataList))
                assignOrder.pageNum = assignOrder.pageNum + 1
                assignOrder.isDataAll = isDataAll
                _this.setData({
                    assignOrder
                })

            } else if (tabTitle == '已关闭') {
                closeOrder.dataList = closeOrder.dataList.concat(_this.formartData(dataList))
                closeOrder.pageNum = closeOrder.pageNum + 1
                closeOrder.isDataAll = isDataAll
                _this.setData({
                    closeOrder
                })
            }
        })
    },

    // 格式化数据
    formartData(dataList) {
        // 格式化数据
        return dataList.map(item => {
            let ext1 = item.ext1
            if (ext1) {
                item.visibleImg = ext1
            } else {
                item.visibleImg = '/profile/static/repair/index/noneImg.png'
            }
            return item;
        })
    },

    // tab 点击切换
    tabClickSwitch(event) {
        console.log('tabClickSwitch', event);
        let _this = this;
        _this.setData({
            tabTitle: event.detail.title
        })
    },

    // 跳转-详情
    jumpDetail(e) {
        console.log('detail', e);
        let _this = this
        let id = e.currentTarget.dataset.obj.id
        wx.navigateTo({
            url: `/pages/reportRepair/assign/detail/detail?id=${id}&title=${_this.data.tabTitle}`,
        })
    },

    // 跳转-重新分配
    jumpAgain() {
        wx.navigateTo({
            url: '/pages/reportRepair/assign/again/again',
        })
    },

    /**
     * 生命周期函数--监听页面初次渲染完成
     */
    onReady() {

    },

    /**
     * 生命周期函数--监听页面显示
     */
    onShow() {
        let _this = this;
        // 
        _this.setData({
            // 重新派单
            resendOrder: {
                pageNum: 1,
                pageSize: 10,
                type: 'anew',
                dataList: [],
                isDataAll: false,
            },
            // 待派单
            pendingOrder: {
                pageNum: 1,
                pageSize: 10,
                type: 'wait',
                dataList: [],
                isDataAll: false,
            },
            // 已派单
            assignOrder: {
                pageNum: 1,
                pageSize: 10,
                type: 'already',
                dataList: [],
                isDataAll: false,
            },
            // 已关闭
            closeOrder: {
                pageNum: 1,
                pageSize: 10,
                type: 'close',
                dataList: [],
                isDataAll: false,
            },
        })
        // 数据
        _this.getDataList('重新派单')
        _this.getDataList('待派单')
        _this.getDataList('已派单')
        _this.getDataList('已关闭')
    },

    /**
     * 生命周期函数--监听页面隐藏
     */
    onHide() {

    },

    /**
     * 生命周期函数--监听页面卸载
     */
    onUnload() {

    },

    /**
     * 页面相关事件处理函数--监听用户下拉动作
     */
    onPullDownRefresh() {
        console.log('onPullDownRefresh', '页面相关事件处理函数--监听用户下拉动作');

    },

    /**
     * 页面上拉触底事件的处理函数
     */
    onReachBottom() {
        console.log('onReachBottom', '页面上拉触底事件的处理函数');
        let _this = this;
        // 获取数据
        _this.getDataList()
    },

    /**
     * 用户点击右上角分享
     */
    onShareAppMessage(e) {
        console.log('onShareAppMessage', e);
        let _this = this;
        let id = e.target.dataset.id;
        let detail = _this.data.reservationDataList.find(item => item.id == id)
        //
        let param = {
            title: detail.title,
            path: "/pages/meeting/invite/invite?id=" + id,
            imageUrl: app.IMG_NAME + detail.roomContent.indoorPicUrlFirst,
        }
        console.log('onShareAppMessage', param);
        return param;
    }
})